@@ -1,6 +1,6 @@
 SpatialLinesDataFrame = function(sl, data, match.ID = TRUE) {
     if (is.character(match.ID)) {
-        row.names(data) = data[match.ID[1]]
+        row.names(data) = data[, match.ID[1]]
         match.ID = TRUE
     }
 	if (match.ID) {
