@@ -13,7 +13,7 @@ image.SpatialGridDataFrame = function(x, attr = 1, xcol = 1, ycol = 2,
 		red=NULL, green=NULL, blue=NULL, axes = FALSE, xlim = NULL, 
 		ylim = NULL, add = FALSE, ..., asp = NA, 
 		setParUsrBB=FALSE, interpolate = FALSE, angle = 0,
-                useRasterImage=!.isSDI(), 
+                useRasterImage=(!.isSDI() && missing(breaks)), breaks, 
 		zlim = range(x[[attr]][is.finite(x[[attr]])])) {
 
 	if (!add) 
@@ -24,22 +24,24 @@ image.SpatialGridDataFrame = function(x, attr = 1, xcol = 1, ycol = 2,
         if (exists("rasterImage") && useRasterImage) {
             if (.isSDI()) warning("Bug in SDI raster handling - your R graphics window may stop displaying output")
             bb <- bbox(x)
-            scl <- function(x, zlim) {
+            scl <- function(xx, zlim) {
                 #dr <- diff(range(x, na.rm = TRUE))
 		dr = diff(zlim)
                 #mx <- min(x, na.rm  = TRUE)
 		mx = zlim[1]
                 if (abs(dr) < .Machine$double.eps)
-                    res <- ifelse(is.na(x), x, 0.5)
-                else res <- (x - mx) / dr
+                    res <- ifelse(is.na(xx), xx, 0.5)
+                else res <- (xx - mx) / dr
                 res
             }
         }
 	if (is.null(red)) {
             if (exists("rasterImage") && useRasterImage) {
-                x <- x[attr]
+	    	if (!missing(breaks))
+			warning("set useRasterImage to FALSE when using breaks")
+                #x <- x[attr]
 #                NAs <- is.na(x[[1]])
-                m <-  scl(t(matrix(x[[1]], x@grid@cells.dim[1],
+                m <-  scl(t(matrix(x[attr][[1]], x@grid@cells.dim[1],
                     x@grid@cells.dim[2])), zlim)
                 m <- matrix(col[as.vector(m) * (length(col)-1) + 1], 
                     nrow(m), ncol(m))
@@ -49,7 +51,7 @@ image.SpatialGridDataFrame = function(x, attr = 1, xcol = 1, ycol = 2,
                     interpolate = interpolate, angle = angle)
             } else {
 		image(as.image.SpatialGridDataFrame(x[attr], xcol, ycol), 
-                  add = TRUE, col = col, zlim = zlim, ...)
+                  add = TRUE, col = col, zlim = zlim, breaks = breaks, ...)
             }
 	} else {
 	    if (is.null(green) || is.null(blue)) 
@@ -57,6 +59,8 @@ image.SpatialGridDataFrame = function(x, attr = 1, xcol = 1, ycol = 2,
 # modified to handle NAs in input (typical for coercion of Spatial Pixels
 # to Spatial Grid)
             if (exists("rasterImage") && useRasterImage) {
+	    	if (!missing(breaks))
+			warning("set useRasterImage to FALSE when using breaks")
                 xd <- x@data[, c(red, green, blue)]
                 NAs <- is.na(xd[, 1]) | is.na(xd[, 2]) | is.na(xd[, 3])
                 if (any(NAs))
@@ -89,7 +93,7 @@ image.SpatialGridDataFrame = function(x, attr = 1, xcol = 1, ycol = 2,
 			x@grid@cells.dim[2], byrow=FALSE)
 		res <- list(x=cv[[xcol]], y=sort(cv[[ycol]]), 
 			z=m[,ncol(m):1,drop=FALSE])
-		image(res, col=levels(fcols), add = TRUE, ...)
+		image(res, col=levels(fcols), add = TRUE, breaks = breaks, ...)
             }
 	}
 }
